@@ -17,17 +17,18 @@
 # along with tgEasy.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-import dotenv
 
-dotenv.load_dotenv()
+from prettyconf import Configuration
+from prettyconf.loaders import EnvFile, Environment
+
+env_file = f"{os.getcwd()}/.env"
+config = Configuration(loaders=[Environment(), EnvFile(filename=env_file)])
 
 
-class Config(object):
+class Config:
     """
     Configuratoins of `tgEasy`.
     """
-    API_ID = int(os.environ.get("API_ID"))
-    API_HASH = os.environ.get("API_HASH")
-    BOT_TOKEN = os.environ.get("BOT_TOKEN")
-    LOGS = os.environ.get("LOGS")
-    PLUGINS = os.environ.get("PLUGINS", None)
\ No newline at end of file
+    LOGS = config("LOGS")
+    PLUGINS = config("PLUGINS", default=None)
+    HANDLERS = list(config("HANDLER", default="/!"))
